==> quick_resto_API-1.0.10.tar.gz: quick_resto_API-1.0.10/quick_resto_API/operations_with_objects/modules/payment_type_operations.py <==
from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
from quick_resto_API.operations_with_objects.system_object import SystemObject
from quick_resto_API.quick_resto_api import QuickRestoApi
from quick_resto_API.quick_resto_objects.modules.core.payment_types import PaymentType

class PaymentTypeOperations(SystemObject):
    def __init__(self, api: QuickRestoApi):
        self._operations_with_objects = OperationsWithObjects(api)

        self._module_name:str = "core.dictionaries.paymenttypes"

    def get_list_of_payment_type(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list:

        json_response = self._operations_with_objects.getList(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result = list()

        for object in json_response:
            result.append(PaymentType(**object))

        return result

    def get_tree_of_payment_type(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list:

        json_response = self._operations_with_objects.getTree(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result = list()

        for object in json_response:
            result.append(PaymentType(**object))

        return result

    def get_payment_type(self, objectId: int, objectRid: int = None) -> PaymentType:
        json_response = self._operations_with_objects.getObject(self._module_name, objectId, objectRid).json()

        return PaymentType(**json_response)

    def get_payment_type_with_subobjects(self, objectId: int, objectRid: int = None) -> PaymentType:
        json_response = self._operations_with_objects.getObjectWithSubobjects(self._module_name, objectId, objectRid).json()

        return PaymentType(**json_response)

    def create_payment_type(self, object: PaymentType,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PaymentType:

        json_response = self._operations_with_objects.createObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PaymentType(**json_response)

    def update_payment_type(self, object: PaymentType,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PaymentType:

        json_response = self._operations_with_objects.updateObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PaymentType(**json_response)

    def remove_payment_type(self, object: PaymentType,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PaymentType:

        json_response = self._operations_with_objects.removeObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PaymentType(**json_response)

    def recover_payment_type(self, object: PaymentType,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PaymentType:

        json_response = self._operations_with_objects.recoverObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PaymentType(**json_response)

==> quick_resto_API-1.0.14.tar.gz: quick_resto_API-1.0.14/quick_resto_API/operations_with_objects/modules/payment_type_operations.py <==
from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
from quick_resto_API.operations_with_objects.system_object import SystemObject
from quick_resto_API.quick_resto_api import QuickRestoApi
from quick_resto_API.quick_resto_objects.modules.core.payment_types import PaymentType

class PaymentTypeOperations(SystemObject):
    def __init__(self, api: QuickRestoApi):
        self._operations_with_objects = OperationsWithObjects(api)

        self._module_name:str = "core.dictionaries.paymenttypes"

    def get_list_of_payment_type(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list[PaymentType]:

        json_response = self._operations_with_objects.getList(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result:list[PaymentType] = list()

        for object in json_response:
            result.append(PaymentType(**object))

        return result

    def get_tree_of_payment_type(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list[PaymentType]:

        json_response = self._operations_with_objects.getTree(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result:list[PaymentType] = list()

        for object in json_response:
            result.append(PaymentType(**object))

        return result

    def get_payment_type(self, objectId: int, objectRid: int = None) -> PaymentType:
        json_response = self._operations_with_objects.getObject(self._module_name, objectId, objectRid).json()

        return PaymentType(**json_response)

    def get_payment_type_with_subobjects(self, objectId: int, objectRid: int = None) -> PaymentType:
        json_response = self._operations_with_objects.getObjectWithSubobjects(self._module_name, objectId, objectRid).json()

        return PaymentType(**json_response)

    def create_payment_type(self, object: PaymentType,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PaymentType:

        json_response = self._operations_with_objects.createObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PaymentType(**json_response)

    def update_payment_type(self, object: PaymentType,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PaymentType:

        json_response = self._operations_with_objects.updateObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PaymentType(**json_response)

    def remove_payment_type(self, object: PaymentType,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PaymentType:

        json_response = self._operations_with_objects.removeObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PaymentType(**json_response)

    def recover_payment_type(self, object: PaymentType,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PaymentType:

        json_response = self._operations_with_objects.recoverObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PaymentType(**json_response)
